@@ -1,4 +1,5 @@
 use std::any::Any;
+use std::fmt::{Debug, Formatter};
 use dddk_core::dddk::command::command::Command;
 
 pub struct SecuredCommand {
@@ -23,6 +24,12 @@ impl SecuredCommand {
     }
 }
 
+impl Debug for SecuredCommand {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        self.command.fmt(f)
+    }
+}
+
 impl Command for SecuredCommand {
     fn as_any(&self) -> &dyn Any {
         self
