@@ -1,4 +1,5 @@
 use std::any::Any;
+use std::fmt::{Debug, Formatter};
 use dddk_core::dddk::query::query::Query;
 
 pub struct SecuredQuery {
@@ -23,6 +24,12 @@ impl SecuredQuery {
     }
 }
 
+impl Debug for SecuredQuery {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        self.query.fmt(f)
+    }
+}
+
 impl Query for SecuredQuery {
     fn as_any(&self) -> &dyn Any {
         self
