@@ -15,6 +15,10 @@ pub mod some_response_for_test {
         fn as_any(&self) -> &dyn Any {
             self
         }
+
+        fn get_response_name(&self) -> String {
+            "AResponse".to_string()
+        }
     }
 
     pub struct AnotherResponse {}
@@ -29,5 +33,9 @@ pub mod some_response_for_test {
         fn as_any(&self) -> &dyn Any {
             self
         }
+
+        fn get_response_name(&self) -> String {
+            "AnotherResponse".to_string()
+        }
     }
 }
\ No newline at end of file
